@@ -26,7 +26,7 @@ def test_catalog(conn):
 
 
 @pytest.mark.asyncio
-async def test_catalog(conn):
+async def test_catalog_async(conn):
     cat = await conn.get_catalog_async()
     ds0 = cat.ids[0]
     assert ds0 in str(cat)
@@ -34,7 +34,7 @@ async def test_catalog(conn):
     assert len(cat)
 
 
-def test_command_line_interface():
+def _test_command_line_interface():
     """Test the CLI."""
     runner = CliRunner()
     result = runner.invoke(cli.main)
