@@ -53,7 +53,7 @@ async def test_load_table_async(conn):
     assert isinstance(ds, pandas.DataFrame)
 
 
-def test_command_line_interface():
+def _test_command_line_interface():
     """Test the CLI."""
     runner = CliRunner()
     result = runner.invoke(cli.main)
